@@ -11,17 +11,25 @@
 # Also put some files in your Google Drive test folder.
 
 use Modern::Perl;
+use Method::Signatures;
 
 use lib '../lib';
 use Net::Google::Drive::Simple::Mirror;
 
+say "-----------------------------------------------------------------";
+say "Show all remote files and their local representation, no download";
+say "-----------------------------------------------------------------";
+
 my $google_docs = Net::Google::Drive::Simple::Mirror->new(
     remote_root   => 'Mirror/Test/Folder',
     local_root    => 'test_data_mirror',
     export_format => ['opendocument','html'],
+    # verbosely download nothing:
     download_condition => sub {
-        say "simply download everything";
-        return 1;
+        my ($self, $remote_file, $local_file) =@_;
+        say "Remote:     ", $remote_file->title();
+        say "`--> Local: $local_file";
+        return 0;
     }
 );
 
